* Do file to be used with agprodols.dta from "Land Distribution and International 
* Agricultural Productivity".  This do-file recreates Table 5 in the paper
* A note on variable names.  Variables with an "i" prefix include values that were
* interpolated, please see Appendix A for a description of the technique used

* Table 5 - OLS regressions
* Column 1 
reg ilnouth dsgini lnavgfarm ///
	if ipercpast~=. & inst~=. & leg_french~=. & plqi~=. & ipercirr~=., robust

* Column 2 - including inputs only
reg ilnouth dsgini lnavgfarm ilnstockh ilnferth ilntracth ilnlaborh ///
    if ipercpast~=. & inst~=. & leg_french~=. & plqi~=. & ipercirr~=., robust

* Column 3 - including inputs, land quality, and irrigation
reg ilnouth dsgini lnavgfarm ilnstockh ilnferth ilntracth ilnlaborh plqi ipercirr ///
    if ipercpast~=. & inst~=. & leg_french~=. , robust

* Column 4 - including inputs, land quality, irrigation, and percent pasture
reg ilnouth dsgini lnavgfarm ilnstockh ilnferth ilntracth ilnlaborh plqi ipercirr ///
    ipercpast if inst~=. & leg_french~=.  , robust

* Column 5 - including all controls but without percent pasture
reg ilnouth dsgini lnavgfarm ilnstockh ilnferth ilntracth ilnlaborh plqi ipercirr ///
    ilexp itfr inst leg_french leg_soc leg_scan leg_germ if ipercpast~=., robust

* Column 6 - including all controls with percent pasture
reg ilnouth dsgini lnavgfarm ilnstockh ilnferth ilntracth ilnlaborh plqi ipercirr ///
    ipercpast ilexp itfr inst leg_french leg_soc leg_scan leg_germ, robust

* Column 7 - including all controls with percent pasture
reg ilnouth dsgini lnavgfarm ilnstockh ilnferth ilntracth ilnlaborh ilnrdh plqi ipercirr ///
    ipercpast ilexp itfr inst leg_french leg_soc leg_scan leg_germ, robust

* Figure 1 - scatter plot of output per hectare against gini
scatter ilnouth dsgini if ipercpast~=. & inst~=. & leg_french~=. & plqi~=. & ipercirr~=., mcolor(black) || ///
	lfit ilnouth dsgini if ipercpast~=. & inst~=. & leg_french~=. & plqi~=. & ipercirr~=., ///
	graphregion(color(white)) xtitle("Landholding Gini Coefficient (g)") ytitle("Log Agric. Output per Ha (intl.$)") ///
	legend(off) lcolor(black) ///
	text(5.6 .35 "Regression Line" "y = 7.07 - 2.12g, R-sq = 0.07" "       (0.38) (0.57)", size(small) just(left))
graph export figure1.png, as(png) replace
	
* Figure 2 - scatter plot of farm size against gini
scatter lnavgfarm dsgini if ipercpast~=. & inst~=. & leg_french~=. & plqi~=. & ipercirr~=., mcolor(black) || ///
	lfit lnavgfarm dsgini if ipercpast~=. & inst~=. & leg_french~=. & plqi~=. & ipercirr~=., ///
	graphregion(color(white)) xtitle("Landholding Gini Coefficient (g)") ytitle("Log Avg. Farm Size (F)") ///
	legend(off) lcolor(black) ///
	text(5.6 .4 "Regression Line" "F = -0.19 + 3.89g, R-sq = 0.15" "       (0.64) (0.45)", size(small) just(left))
graph export figure2.png, as(png) replace
    

